diff -ur radiusd/share/dictionary radiusd-client_sn/share/dictionary
--- radiusd/share/dictionary	2005-03-09 10:19:56.000000000 -0500
+++ radiusd-client_sn/share/dictionary	2005-03-10 06:30:01.000000000 -0500
@@ -320,9 +320,10 @@
 ATTRIBUTE	SSHA-Password		1094	octets
 ATTRIBUTE	MD5-Password		1095	octets
 ATTRIBUTE	SMD5-Password		1096	octets
+ATTRIBUTE	Client-Short-Name	1097	string	
 
 #
-#	Range:	1097-1199
+#	Range:	1098-1199
 #		unused.
 #
 
diff -ur radiusd/src/include/radius.h radiusd-client_sn/src/include/radius.h
--- radiusd/src/include/radius.h	2005-02-03 21:00:08.000000000 -0500
+++ radiusd-client_sn/src/include/radius.h	2005-03-10 06:30:41.000000000 -0500
@@ -200,6 +200,7 @@
 #define PW_MD5_PASSWORD			1095
 #define PW_SMD5_PASSWORD		1096
 
+#define PW_CLIENT_SHORT_NAME		1097
 /*
  *	Integer Translations
  */
diff -ur radiusd/src/modules/rlm_preprocess/rlm_preprocess.c radiusd-client_sn/src/modules/rlm_preprocess/rlm_preprocess.c
--- radiusd/src/modules/rlm_preprocess/rlm_preprocess.c	2005-02-15 13:22:57.000000000 -0500
+++ radiusd-client_sn/src/modules/rlm_preprocess/rlm_preprocess.c	2005-03-10 06:28:22.000000000 -0500
@@ -388,6 +388,10 @@
 /*
  *	If the NAS wasn't smart enought to add a NAS-IP-Address
  *	to the request, then add it ourselves.
+ *	
+ *	Note also that this is a server configuration item,
+ *	and will NOT make it to any packets being sent from
+ *	the server.
  */
 static int add_nas_attr(REQUEST *request)
 {
@@ -404,6 +408,22 @@
 		ip_hostname(nas->strvalue, sizeof(nas->strvalue), nas->lvalue);
 		pairadd(&request->packet->vps, nas);
 	}
+	return 0;
+}
+
+/*	
+ *	Note also that these are server configuration items,
+ *	and will NOT make it to any packets being sent from
+ *	the server.
+ */
+
+
+static int add_client_attr(REQUEST *request)
+{
+	VALUE_PAIR *client_attr = NULL;
+	RADCLIENT *client = NULL;
+
+	
 
 	/*
 	 *	Add in a Client-IP-Address, to tell the user
@@ -412,18 +432,40 @@
 	 *	Note that this MAY BE different from the NAS-IP-Address,
 	 *	especially if the request is being proxied.
 	 *
-	 *	Note also that this is a server configuration item,
-	 *	and will NOT make it to any packets being sent from
-	 *	the server.
 	 */
-	nas = paircreate(PW_CLIENT_IP_ADDRESS, PW_TYPE_IPADDR);
-	if (!nas) {
-	  radlog(L_ERR, "No memory");
-	  return -1;
+	client_attr = pairfind(request->packet->vps, PW_CLIENT_IP_ADDRESS);
+	if (!client_attr) {
+		client_attr = paircreate(PW_CLIENT_IP_ADDRESS, PW_TYPE_IPADDR);
+		if (!client_attr) {
+			radlog(L_ERR, "No memory");
+			return 1;
+		}
+		client_attr->lvalue = request->packet->src_ipaddr;
+		ip_hostname(client_attr->strvalue, sizeof(client_attr->strvalue), client_attr->lvalue);
+		pairadd(&request->packet->vps, client_attr);
+	}
+
+	/*
+	 * 	Add in a Client-Short-Name, so that we may match on short
+	 * 	name of the client who made the request
+	 */
+	client_attr = NULL;
+	client = client_find(request->packet->src_ipaddr);
+	if(!client)
+		return 1;
+	
+	client_attr = pairfind(request->packet->vps, PW_CLIENT_SHORT_NAME);
+	if (!client_attr) {
+		client_attr = paircreate(PW_CLIENT_SHORT_NAME, PW_TYPE_STRING);
+		if (!client_attr) {
+			radlog(L_ERR, "No memory");
+			return 1;
+		}
+		
+		strncpy(client_attr->strvalue,client->shortname,sizeof(client->shortname)-1);
+		client_attr->strvalue[sizeof(client->shortname)-1] = '\0';
+		pairadd(&request->packet->vps, client_attr);
 	}
-	nas->lvalue = request->packet->src_ipaddr;
-	ip_hostname(nas->strvalue, sizeof(nas->strvalue), nas->lvalue);
-	pairadd(&request->packet->vps, nas);
 	return 0;
 }
 
@@ -523,6 +565,9 @@
 	if (add_nas_attr(request) < 0) {
 		return RLM_MODULE_FAIL;
 	}
+	if (add_client_attr(request) < 0) {
+		return RLM_MODULE_FAIL;
+	}
 
 	hints_setup(data->hints, request);
 
@@ -584,6 +629,10 @@
 	if (add_nas_attr(request) < 0) {
 		return RLM_MODULE_FAIL;
 	}
+	
+	if (add_client_attr(request) < 0) {
+		return RLM_MODULE_FAIL;
+	}
 
 	r = hints_setup(data->hints, request);
 
